lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [thread-next>] [day] [month] [year] [list]
Message-ID: <20230621065331.3793767-1-linmiaohe@huawei.com>
Date:   Wed, 21 Jun 2023 14:53:31 +0800
From:   Miaohe Lin <linmiaohe@...wei.com>
To:     <mingo@...hat.com>, <peterz@...radead.org>,
        <juri.lelli@...hat.com>, <vincent.guittot@...aro.org>
CC:     <dietmar.eggemann@....com>, <rostedt@...dmis.org>,
        <bsegall@...gle.com>, <mgorman@...e.de>, <bristot@...hat.com>,
        <vschneid@...hat.com>, <linux-kernel@...r.kernel.org>,
        <linmiaohe@...wei.com>
Subject: [PATCH] sched/fair: fix possible active balance misbehavior

In LBF_DST_PINNED case, env.dst_cpu won't be equal to this_cpu. So when
need_active_balance() returns true, env.dst_cpu should be used to do the
active balance stuff instead of this_cpu.

Fixes: 88b8dac0a14c ("sched: Improve balance_cpu() to consider other cpus in its group as target of (pinned) task")
Signed-off-by: Miaohe Lin <linmiaohe@...wei.com>
---
 kernel/sched/fair.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/kernel/sched/fair.c b/kernel/sched/fair.c
index 5e90e9658528..28ff831ee847 100644
--- a/kernel/sched/fair.c
+++ b/kernel/sched/fair.c
@@ -10968,14 +10968,14 @@ static int load_balance(int this_cpu, struct rq *this_rq,
 			/*
 			 * Don't kick the active_load_balance_cpu_stop,
 			 * if the curr task on busiest CPU can't be
-			 * moved to this_cpu:
+			 * moved to env.dst_cpu:
 			 */
-			if (!cpumask_test_cpu(this_cpu, busiest->curr->cpus_ptr)) {
+			if (!cpumask_test_cpu(env.dst_cpu, busiest->curr->cpus_ptr)) {
 				raw_spin_rq_unlock_irqrestore(busiest, flags);
 				goto out_one_pinned;
 			}
 
 			/* Record that we found at least one task that could run on this_cpu */
 			env.flags &= ~LBF_ALL_PINNED;
 
 			/*
@@ -10985,7 +10985,7 @@ static int load_balance(int this_cpu, struct rq *this_rq,
 			 */
 			if (!busiest->active_balance) {
 				busiest->active_balance = 1;
-				busiest->push_cpu = this_cpu;
+				busiest->push_cpu = env.dst_cpu;
 				active_balance = 1;
 			}
 			raw_spin_rq_unlock_irqrestore(busiest, flags);
@@ -10968,14 +10968,14 @@ static int load_balance(int this_cpu, struct rq *this_rq,
 			}
 
-			/* Record that we found at least one task that could run on this_cpu */
+			/* Record that we found at least one task that could run on env.dst_cpu */
 			env.flags &= ~LBF_ALL_PINNED;
 
-- 
2.27.0

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ